function [Se, Sp, TPR, FPR, PPV, NPV] = ROCMEANSTD(fun, threshold, F5)
    
    indexNP     = find(F5>=4.0);            %   index of positive (osteo: disease detected) events according to the Gold standard
    NP          = length(indexNP);
    
    OSTEOMEAN = mean(fun(indexNP))
    OSTEOSTD = std(fun(indexNP))
    
    
    indexNM     = find(F5<=2.5);            %   index of negative (no osteo: healthy) events according to the Gold standard
    NM          = length(indexNM);
    
    HEALTHYMEAN = mean(fun(indexNM))
    HELATHYSTD = std(fun(indexNM))
    
    %   The contingency table
    indexTP = find(fun >= threshold);   
    indexTP = intersect(indexNP, indexTP);  %   amount of true positive events correctly rated by the threshold 
    TP      = length(indexTP);
    
    indexTP = find(fun >= threshold);   
    indexFP = setdiff(indexNP, indexTP);    %   amount of true positive events incorrectly rated by the threshold 
    FP      = length(indexFP);
    
    indexTN = find(fun <= threshold);     
    indexTN = intersect(indexNM, indexTN);  %   amount of true negative events correctly rated by the threshold 
    TN      = length(indexTN);
        
    indexTN = find(fun <= threshold);
    indexFN = setdiff(indexNM, indexTN);    %   amount of true negative events incorrectly rated by the threshold 
    FN      = length(indexFN);
    
    Se = TP/NP;         %   Sensitivity
    Sp = TN/NM;         %   Specificity
    
    TPR = Se;           %   True positive rate
    FPR = 1-Sp;         %   False positive rate
    
    %   Positive (PPV) and negative (NPV) predictive values are the probability to rate correctly an event using the index
    PPV = TP/(TP+FP);   %   Positive predictive value
    NPV = TN/(TN+FN);   %   Negative predictive value
    
end

