%   This file does de-embedding of the original *.csv data using cable data
clear;
[FileTemp, Path] = uigetfile('*.csv','Select the data file to open', 'MultiSelect', 'on');
if ~iscell(FileTemp) 
    FileName{1} = FileTemp;
else
    FileName = FileTemp;
end    

for m = 1:length(FileName)        
    [S11, S21, f] = osteo(FileName{m});    
    display(FileName{m});
    NewName = strcat('D', FileName{m}(1:end-4));
    save(NewName, 'S11', 'S21', 'f');     
end

function [S11, S21, f] = osteo(datafile)
    % read one data file
    % plot four data sets
    % When running function, enter name of data file within single quotes
    % Copyright Douglas Sondak 2018
    %=====================================================================

    %---------------------------------
    % read data file
    %---------------------------------
    fid = fopen(datafile);                              % open file
    setno = 0;                                          % initialize data set number (4 sets per file)
    icount = 0;                                         % line counter for each set
    while ~feof(fid)                                    % read each line until end of file
    tline = fgetl(fid);                             % read 1 line
    if strcmp(tline(1:3),'BEG')                     % if it starts with 'BEG', new data set
        setno = setno + 1;                          % data set number
        tline = fgetl(fid);                         % get first line of numerical data
        while ~strcmp(tline(1:3),'END')             % read numbers until 'END' is reached
            icount = icount + 1;                    % line counter for each set
            vals = strsplit(tline,',');             % split values at comma, returns cell array with character strings
            x(icount,setno) = str2double(vals{1});  % extract first value from character data
            y(icount,setno) = str2double(vals{2});  % extract second value from character data
            tline = fgetl(fid);                     % read next line from file
        end
        icount = 0;                                 % reset line number counter for next data set
    end
    end
    %---------------------------------
    % conversion
    %---------------------------------
    S11dB = y(:, 1);
    S21dB = y(:, 2);
    S11de = y(:, 3);
    S21de = y(:, 4);

    S11mag = 10.^(S11dB/20);
    S21mag = 10.^(S21dB/20);
    S11 = S11mag.*exp(j*S11de/180*pi);
    S21 = S21mag.*exp(j*S21de/180*pi);
    f   = x(:, 1);    %   frequency, Hz
    [S11, S21, f] = deembed(S11, S21, f);
end

function [S11, S21, f] = deembed(S11X, S21X, f)
    % Note:
    % As the provided data does not have S12 and S22 measurements, I assume
    % S12 = S21
    % S22 = S11
    % The script captures the workflow to do de-embedding
    % First network
    data = load('S_CABLE_L.mat');
    S11 = reshape(data.S11,1,1,numel(data.f));
    S21 = reshape(data.S21,1,1,numel(data.f));
    s1 = sparameters([S11 S21;S21 S11], data.f);
    %%
    % Third network
    data = load('S_CABLE_R.mat');
    S11 = reshape(data.S11,1,1,numel(data.f));
    S21 = reshape(data.S21,1,1,numel(data.f));
    s3 = sparameters([S11 S21;S21 S11], data.f);
    %%
    % Cascaded network
    S11 = reshape(S11X,1,1,numel(f));
    S21 = reshape(S21X,1,1,numel(f));
    s = sparameters([S11 S21;S21 S11], f);
    %%
    s2 = deembedsparams(s,s1,s3);
    % To extract individual network parameters from sparameters object, use rfparam
    S11 = rfparam(s2,1,1);
    S21 = rfparam(s2,2,1);
end